@@ -11,7 +11,7 @@ def serialize_session_cancellation(cancel: SessionCancellation) -> Dict:
     :param cancel: Object to convert
     :return: Converted session cancellation
     """
-    d = {"method": cancel.method}
+    d = {"strategy": cancel.strategy}
 
     for k, v in cancel.options.items():
         d[str(k)] = str(v)
@@ -27,8 +27,8 @@ def serialize_session_request(request: SessionRequest) -> Dict:
     :return: Converted session request
     """
     return {
-        "match-configuration": serialize_match_config(request.match_config),
-        "session-cancellation": serialize_session_cancellation(request.session_cancellation)
+        "matchConfiguration": serialize_match_config(request.match_config),
+        "sessionCancellation": serialize_session_cancellation(request.session_cancellation)
     }
 
 
@@ -39,7 +39,7 @@ def deserialize_match(d: Dict) -> BrokerMatch:
     :param d: Dictionary to convert
     :return: Converted dictionary
     """
-    return BrokerMatch(d["bit-vector"], d["confidence"])
+    return BrokerMatch(d["bitVector"], d["confidence"])
 
 
 def deserialize_secret_response(d: Dict) -> str:
