@@ -39,7 +39,9 @@ def serialize_schema(schema: AttributeSchema) -> Dict:
     """
     d = {
         "attributeName": schema.attribute_name,
-        "dataType": schema.data_type
+        "dataType": schema.data_type,
+        "averageTokenCount": schema.average_token_count,
+        "weight": schema.weight
     }
 
     d.update({
@@ -76,15 +78,15 @@ def serialize_bloom_filter_config(config: BloomFilterConfig) -> Dict:
     if config.hash_strategy is not None:
         d["hashStrategy"] = config.hash_strategy
 
-    if config.hash_functions is not None:
-        d["hashFunctions"] = config.hash_functions
-
-    if config.filter_size is not None:
-        d["filterSize"] = config.filter_size
+    if config.hash_values is not None:
+        d["hashValues"] = config.hash_values
 
     if config.token_size is not None:
         d["tokenSize"] = config.token_size
 
+    if config.seed is not None:
+        d["seed"] = config.seed
+
     if config.key is not None:
         d["key"] = config.key
 
