@@ -10,6 +10,8 @@ class AttributeSchema:
     """
     attribute_name: str
     data_type: str
+    average_token_count: float
+    weight: float
     options: Dict[str, object] = field(default_factory=dict)
 
 
@@ -20,9 +22,9 @@ class BloomFilterConfig:
     """
     charset: Optional[str] = None
     hash_strategy: Optional[str] = None
-    hash_functions: Optional[int] = None
-    filter_size: Optional[int] = None
+    hash_values: Optional[int] = None
     token_size: Optional[int] = None
+    seed: Optional[int] = None
     key: Optional[str] = None
 
 
