@@ -1,7 +1,7 @@
 from typing import Dict
 
 from .model import ClientConfig, ResolveRequest, PseudonymMatch
-from ..encoder.conversion import serialize_encoder_config
+from ..encoder.conversion import serialize_bloom_filter_config
 
 
 def serialize_client_config(config: ClientConfig) -> Dict:
@@ -25,8 +25,8 @@ def serialize_resolve_request(request: ResolveRequest) -> Dict:
     :return: Converted resolve request
     """
     return {
-        "client-config": serialize_client_config(request.client_config),
-        "encoder-config": serialize_encoder_config(request.encoder_config),
+        "clientConfig": serialize_client_config(request.client_config),
+        "encoderBloomConfig": serialize_bloom_filter_config(request.encoder_bloom_config),
         "pseudonyms": request.pseudonyms
     }
 
